@@ -31,7 +31,10 @@ import (
 	"github.com/apache/skywalking-satellite/plugins/client/grpc/resolvers"
 )
 
-const Name = "grpc-client"
+const (
+	Name     = "grpc-client"
+	ShowName = "GRPC Client"
+)
 
 type Client struct {
 	config.CommonFields
@@ -58,15 +61,34 @@ func (c *Client) Name() string {
 	return Name
 }
 
+func (c *Client) ShowName() string {
+	return ShowName
+}
+
 func (c *Client) Description() string {
 	return "The gRPC client is a sharing plugin to keep connection with the gRPC server and delivery the data to it."
 }
 
 func (c *Client) DefaultConfig() string {
 	return `
+# The gRPC client finder type
+finder_type: "static"
+
 # The gRPC server address (default localhost:11800), multiple addresses are split by ",".
 server_addr: localhost:11800
 
+# The gRPC kubernetes server address finder
+kubernetes_config:
+  # The kind of resource
+  kind: pod
+  # The resource namespaces
+  namespaces:
+    - default
+  # How to get the address exported port
+  extra_port:
+    # Resource target port
+    port: 11800
+
 # The TLS switch (default false).
 enable_TLS: false
 
