@@ -31,9 +31,13 @@ import (
 	"github.com/apache/skywalking-satellite/internal/pkg/config"
 	"github.com/apache/skywalking-satellite/internal/pkg/log"
 	"github.com/apache/skywalking-satellite/internal/satellite/event"
+	server_grpc "github.com/apache/skywalking-satellite/plugins/server/grpc"
 )
 
-const Name = "nativelog-grpc-forwarder"
+const (
+	Name     = "nativelog-grpc-forwarder"
+	ShowName = "Native Log GRPC Forwarder"
+)
 
 type Forwarder struct {
 	config.CommonFields
@@ -45,6 +49,10 @@ func (f *Forwarder) Name() string {
 	return Name
 }
 
+func (f *Forwarder) ShowName() string {
+	return ShowName
+}
+
 func (f *Forwarder) Description() string {
 	return "This is a synchronization grpc forwarder with the SkyWalking native log protocol."
 }
@@ -74,7 +82,7 @@ func (f *Forwarder) Forward(batch event.BatchEvents) error {
 		if !ok {
 			continue
 		}
-		err := stream.Send(data.Log)
+		err := stream.SendMsg(server_grpc.NewOriginalData(data.Log))
 		if err != nil {
 			log.Logger.Errorf("%s send log data error: %v", f.Name(), err)
 			err = closeStream(stream)
